@@ -120,7 +120,8 @@ class Globals:
 
     SAFE_AMOUNT_OF_TRIPLE_SINGLE_OR_DOUBLE_QUOTES_PLUS_ONE = 4
 
-    STATIC_DIRECTORY_PATH = f'{OS_SEPARATOR}statics'
+    PYTHON_VERSION_PLACEHOLDER = '__PYTHON_VERSION_PLACEHOLDER__'
+    STATIC_DIRECTORY_PATH = f'{OS_SEPARATOR}lib{OS_SEPARATOR}python{PYTHON_VERSION_PLACEHOLDER}{OS_SEPARATOR}site-packages{OS_SEPARATOR}statics'
     PYTHON_LANGUAGE_NAME = 'python'
 
     DEBUG =     '[DEBUG  ] '
@@ -680,7 +681,20 @@ class Globals:
                 return settingValue
 
     def getStaticPackagePath(self) :
-        return getStaticPackagePath()
+        staticPackageList = site.getsitepackages()
+        log.debug(getStaticPackagePath,f'Static packages list: {staticPackageList}. Picking the first one')
+        staticPackage = str(staticPackageList[0])
+        staticPackage = staticPackage.replace(f'{Globals.BACK_SLASH}{Globals.BACK_SLASH}',Globals.OS_SEPARATOR)
+        staticPackage = staticPackage.replace(Globals.BACK_SLASH,Globals.OS_SEPARATOR)
+        staticPackage = staticPackage.replace(f'{Globals.SLASH}{Globals.SLASH}',Globals.OS_SEPARATOR)
+        staticPackage = staticPackage.replace(Globals.SLASH,Globals.OS_SEPARATOR)
+        if staticPackage[-1] == str(Globals.OS_SEPARATOR) :
+            staticPackage = staticPackage[:-1]
+        pythonVersion = Globals.STATIC_DIRECTORY_PATH.replace(Globals.PYTHON_VERSION_PLACEHOLDER, str(self.getApiSetting(AttributeKey.PYTHON_VERSION)))
+        if not pythonVersion in staticPackage :
+            staticPackage = f'{staticPackage}{pythonVersion}'
+        self.debug(f'Static package: "{staticPackage}"')
+        return staticPackage
 
     def searchTreeList(self,search,tree):
         return searchTreeList(search,tree)
@@ -750,16 +764,20 @@ def getStaticPackagePath() :
     if staticPackage[-1] == str(Globals.OS_SEPARATOR) :
         staticPackage = staticPackage[:-1]
     staticPackage = f'{staticPackage}{Globals.STATIC_DIRECTORY_PATH}'
+    staticPackage = staticPackage.replace(Globals.PYTHON_VERSION_PLACEHOLDER, Constant.NOTHING)
     log.debug(getStaticPackagePath,f'Static package: "{staticPackage}"')
     return staticPackage
 
 def searchTreeList(search,tree) :
     def keepSearching(search,history,tree,treeList):
-        for key in tree.keys() :
-            newHistory = f'{history}.{key}'
-            if search and search in newHistory :
-                treeList.append(newHistory)
-            keepSearching(search,newHistory,tree[key], treeList)
+        if dict == type(tree) :
+            for key in tree.keys() :
+                newHistory = f'{history}.{key}'
+                if search and search in newHistory :
+                    treeList.append(newHistory)
+                keepSearching(search,newHistory,tree[key], treeList)
+        else :
+            log.debug(keepSearching,f'"{tree}" is not a dictionary')
     treeList = []
     keepSearching(search,'root',tree,treeList)
     return treeList
